%define anolis_release 1

%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

%define __python /usr/bin/python3
%define init_system systemd

# See: http://www.zarb.org/~jasonc/macros.php
# Or: http://fedoraproject.org/wiki/Packaging:ScriptletSnippets
# Or: http://www.rpm.org/max-rpm/ch-rpm-inside.html

Name:           cloud-init
Version:        19.1.17
Release:        %{anolis_release}%{?dist}
Summary:        Cloud instance init scripts

Group:          System Environment/Base
License:        Dual-licesed GPLv3 or Apache 2.0
URL:            http://launchpad.net/cloud-init

Source0:        cloud-init-19.1.17.tgz

Patch0:         Enable-ipv6-network-by-default.patch
Patch1001:	0001-replace-deprecated-collections-Iterable-with-abc-replacement.patch

BuildArch:      noarch
BuildRoot:      %{_tmppath}

Requires:           systemd
BuildRequires:      systemd
Requires:           systemd-units
BuildRequires:      systemd-units

# These are runtime dependencies, but declared as BuildRequires so that
# - tests can be run here.
# - parts of cloud-init such (setup.py) use these dependencies.
BuildRequires:  python3-requests
BuildRequires:  python3-configobj
BuildRequires:  python3-jsonschema
BuildRequires:  python3-six
BuildRequires:  python3-jinja2
BuildRequires:  python3-pyyaml
BuildRequires:  python3-oauthlib
BuildRequires:  python3-jsonpatch
BuildRequires:  e2fsprogs
BuildRequires:  iproute
BuildRequires:  net-tools
BuildRequires:  procps
BuildRequires:  rsyslog
BuildRequires:  shadow-utils
BuildRequires:  sudo
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

# System util packages needed
%ifarch x86_64 
Requires:       dmidecode
%endif

# Install 'dynamic' runtime reqs from *requirements.txt and pkg-deps.json
Requires:       python3-requests
Requires:       python3-configobj
Requires:       python3-jsonschema
Requires:       python3-six
Requires:       python3-jinja2
Requires:       python3-pyyaml
Requires:       python3-oauthlib
Requires:       python3-jsonpatch
Requires:       e2fsprogs
Requires:       iproute
Requires:       net-tools
Requires:       procps
Requires:       rsyslog
Requires:       shadow-utils
Requires:       sudo
Requires:       python3-devel
Requires:       python3-setuptools

Requires(post):       systemd
Requires(preun):      systemd
Requires(postun):     systemd

%description
Cloud-init is a set of init scripts for cloud instances.  Cloud instances
need special scripts to run during initialization to retrieve and install
ssh keys and to let the user run various scripts.

%prep
%autosetup -n cloud-init-19.1.17 -p1

%build
%{__python} setup.py build

%install
%{__python} setup.py install -O1 \
            --skip-build --root $RPM_BUILD_ROOT \
            --init-system=%{init_system}

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/rsyslog.d
cp -p tools/21-cloudinit.conf \
      $RPM_BUILD_ROOT/%{_sysconfdir}/rsyslog.d/21-cloudinit.conf

# Remove the tests
rm -rf $RPM_BUILD_ROOT%{python_sitelib}/tests

# Required dirs...
mkdir -p $RPM_BUILD_ROOT/%{_sharedstatedir}/cloud
mkdir -p $RPM_BUILD_ROOT/%{_libexecdir}/%{name}

# patch in the full version to version.py
version_pys=$(cd "$RPM_BUILD_ROOT" && find . -name version.py -type f)
[ -n "$version_pys" ] ||
   { echo "failed to find 'version.py' to patch with version." 1>&2; exit 1; }
( cd "$RPM_BUILD_ROOT" &&
  sed -i "s,@@PACKAGED_VERSION@@,%{version}-%{release}," $version_pys )

%clean
rm -rf $RPM_BUILD_ROOT

%post
if [ $1 -eq 1 ]
then
    /bin/systemctl enable cloud-config.service     >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-final.service      >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-init.service       >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-init-local.service >/dev/null 2>&1 || :
fi
grep -Eiq 'qboot|quick boot' /etc/image-id && sed -i "/Before=sshd.service/d" /usr/lib/systemd/system/cloud-init.service
grep -Eiq 'qboot|quick boot' /etc/image-id && sed -i "/Before=sshd-keygen.service/d" /usr/lib/systemd/system/cloud-init.service
grep -Eiq 'qboot|quick boot' /etc/image-id && sed -i "s/Before=network-online.target/After=network-online.target/g" /usr/lib/systemd/system/cloud-init.service
grep -Eiq 'qboot|quick boot' /etc/image-id && sed -i "/Wants=network-pre.target/d" /usr/lib/systemd/system/cloud-init-local.service
grep -Eiq 'qboot|quick boot' /etc/image-id && sed -i "/Before=NetworkManager.service/d" /usr/lib/systemd/system/cloud-init-local.service
grep -Eiq 'qboot|quick boot' /etc/image-id && sed -i "s/Before=network-pre.target/Requires=network-online.target/g" /usr/lib/systemd/system/cloud-init-local.service
grep -Eiq 'qboot|quick boot' /etc/image-id && sed -i "s/After=systemd-remount-fs.service/After=systemd-remount-fs.service network-online.target/g" /usr/lib/systemd/system/cloud-init-local.service
ln -sf /sys/firmware/qemu_fw_cfg/by_name/etc/cloud-init/vendor-data/raw /etc/cloud/cloud.cfg.d/aliyun_cloud.cfg

%preun
if [ $1 -eq 0 ]
then
    /bin/systemctl --no-reload disable cloud-config.service >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-final.service  >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-init.service   >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-init-local.service >/dev/null 2>&1 || :
fi

%postun
/bin/systemctl daemon-reload >/dev/null 2>&1 || :

%files
/lib/udev/rules.d/66-azure-ephemeral.rules
/usr/lib/systemd/system-generators/cloud-init-generator
%{_unitdir}/cloud-*
%{_sysconfdir}/NetworkManager/dispatcher.d/hook-network-manager
%{_sysconfdir}/dhcp/dhclient-exit-hooks.d/hook-dhclient
# Program binaries
%{_bindir}/cloud-init*
%{_bindir}/cloud-id*
# Docs
%doc LICENSE ChangeLog TODO.rst requirements.txt
%doc %{_defaultdocdir}/cloud-init/*
# Configs
%config(noreplace)      %{_sysconfdir}/cloud/cloud.cfg
%dir                    %{_sysconfdir}/cloud/cloud.cfg.d
%config(noreplace)      %{_sysconfdir}/cloud/cloud.cfg.d/*.cfg
%config(noreplace)      %{_sysconfdir}/cloud/cloud.cfg.d/README
%dir                    %{_sysconfdir}/cloud/templates
%config(noreplace)      %{_sysconfdir}/cloud/templates/*
%config(noreplace) %{_sysconfdir}/rsyslog.d/21-cloudinit.conf
# Bash completion script
%{_datadir}/bash-completion/completions/cloud-init
%{_libexecdir}/%{name}
%dir %{_sharedstatedir}/cloud
# Python code is here...
%{python_sitelib}/*
/usr/lib/cloud-init/ds-identify
/usr/lib/cloud-init/uncloud-init
/usr/lib/cloud-init/write-ssh-key-fingerprints

%changelog
* Fri Jul 01 2022 happy_orange <songnannan@linux.alibaba.com> - 19.1.17
- rollback to 19.1.17

* Thu Apr 07 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 22.1-1
- init from upstream
